@@ -18,7 +18,7 @@ our @EXPORT = qw(
     $USE_REGISTRAR_SERVERS
 );
 
-our $VERSION = '1.18';
+our $VERSION = '1.19';
 
 our $USE_REGISTRAR_SERVERS;
 our $CACHE_DIR;
@@ -479,7 +479,7 @@ sub _dates_int_ru {
     }
 
     $reg_till  = decode_date( $reg_till,  $format );
-    $free_date = decode_date( $free_date, $format );
+    $free_date = decode_date( $free_date, '%Y-%m-%d' );
 
     if ( !$reg_till && $free_date ) {
         $reg_till = $free_date - 33 * ONE_DAY;
